@@ -56,7 +56,7 @@ class Index:
     def load_all(self):
         from mtdata.index import (
             statmt, paracrawl, tilde, joshua_indian, unitednations, wikimatrix, other, neulab_tedtalks,
-            elrc_share, ai4bharat, eu, linguatools, anuvaad)
+            elrc_share, ai4bharat, eu, linguatools, anuvaad, allenai_nllb)
         from mtdata.index.opus import opus_index, jw300, opus100
         subsets = [
             ('Statmt.org', statmt.load),
@@ -75,6 +75,7 @@ class Index:
             ('EU', eu.load_all),
             ('LinguaTools', linguatools.load_all),
             ('Anuvaad', anuvaad.load_all),
+            ('AllenAi_NLLB', allenai_nllb.load_all),
         ]
         for name, loader in subsets:
             loader(self)
