@@ -198,7 +198,29 @@ class TarPath(ArchivedPath):
                     return   # extracted by parallel process
                 log.info(f"extracting {self.root}")
                 with tarfile.open(self.root) as tar:
-                    tar.extractall(out_path)
+                    
+                    import os
+                    
+                    def is_within_directory(directory, target):
+                        
+                        abs_directory = os.path.abspath(directory)
+                        abs_target = os.path.abspath(target)
+                    
+                        prefix = os.path.commonprefix([abs_directory, abs_target])
+                        
+                        return prefix == abs_directory
+                    
+                    def safe_extract(tar, path=".", members=None, *, numeric_owner=False):
+                    
+                        for member in tar.getmembers():
+                            member_path = os.path.join(path, member.name)
+                            if not is_within_directory(path, member_path):
+                                raise Exception("Attempted Path Traversal in Tar File")
+                    
+                        tar.extractall(path, members, numeric_owner=numeric_owner) 
+                        
+                    
+                    safe_extract(tar, out_path)
                 valid_path.touch()
         return out_path
 
@@ -210,4 +232,13 @@ class TarPath(ArchivedPath):
             if self.root.name.endswith(ext):
                 dir_name = name[:-len(ext)]
                 break
-        return dir_name
\ No newline at end of file
+        return dir_name
+
+
+def format_byte_size(n: int) -> str:
+    """formats byte count into human readable size such as kB, MB, GB..."""
+    for power, unit in [(12, 'TB'), (9, 'GB'), (6, 'MB'), (3, 'kB')]:
+        if n >= (10 ** power):
+            m = n / 10 ** power
+            return f'{m:.2f}'.rstrip('0') + f' {unit}'
+    return f'{n}B'
